Package: vegawidget
Version: 0.5.0
Title: 'Htmlwidget' for 'Vega' and 'Vega-Lite'
Description: 'Vega' and 'Vega-Lite' parse text in 'JSON' notation to render 
  chart-specifications into 'HTML'. This package is used to facilitate the 
  rendering. It also provides a means to interact with signals, events,
  and datasets in a 'Vega' chart using 'JavaScript' or 'Shiny'.
Authors@R: c(
    person(
      given = "Ian", 
      family = "Lyttle", 
      email = "ijlyttle@me.com", 
      role = c("aut", "cre"), 
      comment = c(ORCID = "0000-0001-9962-4849")
    ),
    person("Vega/Vega-Lite Developers", role = c("aut")),
    person(
      given = "Alicia", 
      family = "Schep",
      email = "aschep@gmail.com",
      role = c("ctb"),
      comment = c(ORCID = "orcid.org/0000-0002-3915-0618")
    ),
    person(
      given = "Stuart", 
      family = "Lee", 
      email = "stuart.andrew.lee@gmail.com", 
      role = c("ctb")
    ),
    person("Kanit", "Wongsuphasawat", comment = "Vega/Vega-Lite library", role = c("ctb")),
    person("Dominik", "Moritz", comment = "Vega/Vega-Lite library", role = c("ctb")),
    person("Arvind", "Satyanarayan", comment = "Vega/Vega-Lite library", role = c("ctb")),
    person("Jeffrey", "Heer", comment = "Vega/Vega-Lite library", role = c("ctb")),
    person("Mike", "Bostock", comment = "D3 library", role = c("ctb"))
  )
SystemRequirements: To use image functions for MacOS: X11
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
ByteCompile: true
URL: https://vegawidget.github.io/vegawidget/,
        https://github.com/vegawidget/vegawidget
BugReports: https://github.com/vegawidget/vegawidget/issues
RoxygenNote: 7.3.0
VignetteBuilder: knitr
Depends: R (>= 2.10)
Imports: jsonlite, htmlwidgets, assertthat, rlang, glue, magrittr,
        htmltools, digest, utils
Suggests: spelling, knitr, rmarkdown, listviewer, testthat (>= 3.0.0),
        yaml, fs, usethis (>= 1.5.0), readr, tibble, lubridate, V8 (>=
        4.0), withr, learnr, rsvg, dplyr, png, conflicted, here, shiny,
        purrr, rsconnect
Language: en-US
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2024-01-13 16:41:39 UTC; ijlyttle
Author: Ian Lyttle [aut, cre] (<https://orcid.org/0000-0001-9962-4849>),
  Vega/Vega-Lite Developers [aut],
  Alicia Schep [ctb] (<https://orcid.org/0000-0002-3915-0618>),
  Stuart Lee [ctb],
  Kanit Wongsuphasawat [ctb] (Vega/Vega-Lite library),
  Dominik Moritz [ctb] (Vega/Vega-Lite library),
  Arvind Satyanarayan [ctb] (Vega/Vega-Lite library),
  Jeffrey Heer [ctb] (Vega/Vega-Lite library),
  Mike Bostock [ctb] (D3 library)
Maintainer: Ian Lyttle <ijlyttle@me.com>
Repository: CRAN
Date/Publication: 2024-01-13 17:20:02 UTC
Built: R 4.6.0; ; 2026-04-28 22:59:49 UTC; unix
