# Generated by roxygen2: do not edit by hand

S3method(as_vegaspec,character)
S3method(as_vegaspec,default)
S3method(as_vegaspec,json)
S3method(as_vegaspec,list)
S3method(as_vegaspec,vegaspec)
S3method(as_vegaspec,vegawidget)
S3method(format,vegaspec)
S3method(print,JS_EVAL)
S3method(print,vegaspec)
S3method(print,vw_handler)
export("%>%")
export(.vw_handler_body)
export(.vw_handler_def)
export(JS)
export(as_vegaspec)
export(glue_js)
export(knit_print.vegaspec)
export(renderVegawidget)
export(s3_register)
export(use_vegawidget)
export(use_vegawidget_interactive)
export(vega_embed)
export(vega_schema)
export(vega_version)
export(vega_version_all)
export(vega_version_available)
export(vegawidget)
export(vegawidgetOutput)
export(vw_add_data_listener)
export(vw_add_event_listener)
export(vw_add_signal_listener)
export(vw_as_json)
export(vw_autosize)
export(vw_examine)
export(vw_fetch)
export(vw_handler)
export(vw_handler_add_effect)
export(vw_handler_body_compose)
export(vw_handler_compose)
export(vw_handler_data)
export(vw_handler_event)
export(vw_handler_signal)
export(vw_load)
export(vw_rename_datasets)
export(vw_serialize_data)
export(vw_set_base_url)
export(vw_shiny_demo)
export(vw_shiny_get_data)
export(vw_shiny_get_event)
export(vw_shiny_get_signal)
export(vw_shiny_run)
export(vw_shiny_set_data)
export(vw_shiny_set_signal)
export(vw_spec_version)
export(vw_to_bitmap)
export(vw_to_svg)
export(vw_to_vega)
export(vw_write_png)
export(vw_write_svg)
importFrom(htmlwidgets,JS)
importFrom(magrittr,"%>%")
importFrom(rlang,`%||%`)
