#### vegaspec functions ####

#' Coerce to vegaspec
#'
#' See \code{vegawidget::\link[vegawidget]{as_vegaspec}} for details.
#'
#' @name as_vegaspec
#' @rdname as_vegaspec
#' @importFrom vegawidget as_vegaspec
#' @export
#'
NULL

#' Coerce vegaspec to JSON
#'
#' See \code{vegawidget::\link[vegawidget]{vw_as_json}} for details.
#'
#' @name vw_as_json
#' @rdname vw_as_json
#' @importFrom vegawidget vw_as_json
#' @export
#'
NULL

#### print functions ####

#' Knit-print method
#'
#' See \code{vegawidget::\link[vegawidget]{knit_print.vegaspec}} for details,
#' particularly on additional packages that may have to be installed.
#'
#' @name knit_print.vegaspec
#' @rdname knit_print.vegaspec
#' @importFrom vegawidget knit_print.vegaspec
#' @export
#'
NULL

#### vegawidget functions ####

#' Create a Vega/Vega-Lite htmlwidget
#'
#' See \code{vegawidget::\link[vegawidget]{vegawidget}} for details.
#'
#' @name vegawidget
#' @rdname vegawidget
#' @importFrom vegawidget vegawidget
#' @export
#'
NULL

#' Vega embed options
#'
#' See \code{vegawidget::\link[vegawidget]{vega_embed}} for details.
#'
#' @name vega_embed
#' @rdname vega_embed
#' @importFrom vegawidget vega_embed
#' @export
#'
NULL

#' Set base URL
#'
#' See \code{vegawidget::\link[vegawidget]{vw_set_base_url}} for details.
#'
#' @name vw_set_base_url
#' @rdname vw_set_base_url
#' @importFrom vegawidget vw_set_base_url
#' @export
#'
NULL

#### image functions ####

#' Create or write image
#'
#' See \code{vegawidget::\link[vegawidget]{image}} for details.
#'
#' @name image
#' @importFrom vegawidget
#'           vw_to_svg vw_to_bitmap vw_write_png vw_write_svg
#' @aliases  vw_to_svg vw_to_bitmap vw_write_png vw_write_svg
#' @export   vw_to_svg vw_to_bitmap vw_write_png vw_write_svg
#'
NULL

#### shiny functions ####

#' Shiny-output for vegawidget
#'
#' See \code{vegawidget::\link[vegawidget]{vegawidgetOutput}} for details.
#'
#' @name vegawidgetOutput
#' @rdname vegawidgetOutput
#' @importFrom vegawidget vegawidgetOutput
#' @export
#'
NULL

#' Render shiny-output for vegawidget
#'
#' See \code{vegawidget::\link[vegawidget]{renderVegawidget}} for details.
#'
#' @name renderVegawidget
#' @rdname renderVegawidget
#' @importFrom vegawidget renderVegawidget
#' @export
#'
NULL


