#### listener functions ####

#' JavaScript listeners for vegawidget
#'
#' See \code{vegawidget::\link[vegawidget]{add-listeners}} for details.
#'
#' @name vw-add-listeners
#' @importFrom vegawidget
#'          vw_add_data_listener vw_add_signal_listener vw_add_event_listener
#' @aliases vw_add_data_listener vw_add_signal_listener vw_add_event_listener
#' @export  vw_add_data_listener vw_add_signal_listener vw_add_event_listener
#'
NULL

#### handler functions ####

#' JavaScript handlers for vegawidget
#'
#' See \code{vegawidget::\link[vegawidget]{vw_handler_signal}},
#'   \code{vegawidget::\link[vegawidget]{vw_handler_add_effect}}, for details.
#'
#' @name vw-handlers
#' @importFrom vegawidget
#'   vw_handler_data vw_handler_signal vw_handler_event vw_handler_add_effect
#' @aliases
#'   vw_handler_data vw_handler_signal vw_handler_event vw_handler_add_effect
#' @export
#'   vw_handler_data vw_handler_signal vw_handler_event vw_handler_add_effect
#'
NULL

#### shiny functions ####

#' Shiny getters for vegawidget
#'
#' See \code{vegawidget::\link[vegawidget]{shiny-getters}} for details.
#'
#' @name vw-shiny-getters
#' @importFrom vegawidget
#'           vw_shiny_get_data vw_shiny_get_signal vw_shiny_get_event
#' @aliases  vw_shiny_get_data vw_shiny_get_signal vw_shiny_get_event
#' @export   vw_shiny_get_data vw_shiny_get_signal vw_shiny_get_event
#'
NULL

#' Shiny setters for vegawidget
#'
#' See \code{vegawidget::\link[vegawidget]{shiny-setters}} for details.
#'
#' @name vw-shiny-setters
#' @importFrom vegawidget
#'          vw_shiny_set_data vw_shiny_set_signal
#' @aliases vw_shiny_set_data vw_shiny_set_signal
#' @export  vw_shiny_set_data vw_shiny_set_signal
#'
NULL
